 /**
 * @file sync-anchor.h
 *  
 * @brief Anchornode specific definitions & functions
 */
#ifndef SYNC_ANCHOR_H_INCLUDED
#define SYNC_ANCHOR_H_INCLUDED

#include <stdio.h>
#include <string.h>
#include <io.h>
#include <dev/usartavr.h>
#include <hardware/btn-hardware.h>
#include <sys/atom.h> // NutEnterCritical()

/** 
 * The baud rate that is used when communicating with the PC.
 * Make sure it is equally set for the timestampserver.
 */	
#define ANCHORNODE_BAUD_RATE 115200

/** 
 * This character is sent when the anchornode requests a timestamp to the PC.
 * Make sure it is equally set for the timestampserver.
 */	
#define REQ_CHAR "#" //"\255"

/** 
 * This character is sent when the anchornode acknowledges a timestamp received
 * from the PC.
 * Make sure it is equally set for the timestampserver.
 */	
#define ACK_CHAR "&"  //"\254"

/**
 * The length (in Bytes) of the timestamp transmitted from the pc to the
 * anchornode. This length depends only on wether IM or BP-ISA is used
 * and not on the definition of SYNC_RTT.
 */
#define SYNC_ANCHOR_TSTAMP_LEN 12

/*******************************************************************************
 * sync_anchor_update_timestamp
 ******************************************************************************/
/**
 * @brief Requests a timestamp from the timestampserver running on the PC
 * 
 * The requested timestamp is stored in the variable bytestream.
 */
void sync_anchor_get_timestamp(char * bytestream);

#endif // SYNC_ANCHOR_H_INCLUDED
